Class: Aws::CognitoIdentity::Types::CreateIdentityPoolInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentity/types.rb

Overview

Input to the CreateIdentityPool action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allow_classic_flowBoolean

Enables or disables the Basic (Classic) authentication flow. For more information, see Identity Pools (Federated Identities) Authentication Flow in the Amazon Cognito Developer Guide.



118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/aws-sdk-cognitoidentity/types.rb', line 118

class CreateIdentityPoolInput < Struct.new(
  :identity_pool_name,
  :allow_unauthenticated_identities,
  :allow_classic_flow,
  :supported_login_providers,
  :developer_provider_name,
  :open_id_connect_provider_arns,
  :cognito_identity_providers,
  :saml_provider_arns,
  :identity_pool_tags)
  SENSITIVE = []
  include Aws::Structure
end

#allow_unauthenticated_identitiesBoolean

TRUE if the identity pool supports unauthenticated logins.



118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/aws-sdk-cognitoidentity/types.rb', line 118

class CreateIdentityPoolInput < Struct.new(
  :identity_pool_name,
  :allow_unauthenticated_identities,
  :allow_classic_flow,
  :supported_login_providers,
  :developer_provider_name,
  :open_id_connect_provider_arns,
  :cognito_identity_providers,
  :saml_provider_arns,
  :identity_pool_tags)
  SENSITIVE = []
  include Aws::Structure
end

#cognito_identity_providersArray<Types::CognitoIdentityProvider>

An array of Amazon Cognito user pools and their client IDs.



118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/aws-sdk-cognitoidentity/types.rb', line 118

class CreateIdentityPoolInput < Struct.new(
  :identity_pool_name,
  :allow_unauthenticated_identities,
  :allow_classic_flow,
  :supported_login_providers,
  :developer_provider_name,
  :open_id_connect_provider_arns,
  :cognito_identity_providers,
  :saml_provider_arns,
  :identity_pool_tags)
  SENSITIVE = []
  include Aws::Structure
end

#developer_provider_nameString

The "domain" by which Cognito will refer to your users. This name acts as a placeholder that allows your backend and the Cognito service to communicate about the developer provider. For the DeveloperProviderName, you can use letters as well as period (.), underscore (_), and dash (-).

Once you have set a developer provider name, you cannot change it. Please take care in setting this parameter.



118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/aws-sdk-cognitoidentity/types.rb', line 118

class CreateIdentityPoolInput < Struct.new(
  :identity_pool_name,
  :allow_unauthenticated_identities,
  :allow_classic_flow,
  :supported_login_providers,
  :developer_provider_name,
  :open_id_connect_provider_arns,
  :cognito_identity_providers,
  :saml_provider_arns,
  :identity_pool_tags)
  SENSITIVE = []
  include Aws::Structure
end

#identity_pool_nameString

A string that you provide.



118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/aws-sdk-cognitoidentity/types.rb', line 118

class CreateIdentityPoolInput < Struct.new(
  :identity_pool_name,
  :allow_unauthenticated_identities,
  :allow_classic_flow,
  :supported_login_providers,
  :developer_provider_name,
  :open_id_connect_provider_arns,
  :cognito_identity_providers,
  :saml_provider_arns,
  :identity_pool_tags)
  SENSITIVE = []
  include Aws::Structure
end

#identity_pool_tagsHash<String,String>

Tags to assign to the identity pool. A tag is a label that you can apply to identity pools to categorize and manage them in different ways, such as by purpose, owner, environment, or other criteria.



118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/aws-sdk-cognitoidentity/types.rb', line 118

class CreateIdentityPoolInput < Struct.new(
  :identity_pool_name,
  :allow_unauthenticated_identities,
  :allow_classic_flow,
  :supported_login_providers,
  :developer_provider_name,
  :open_id_connect_provider_arns,
  :cognito_identity_providers,
  :saml_provider_arns,
  :identity_pool_tags)
  SENSITIVE = []
  include Aws::Structure
end

#open_id_connect_provider_arnsArray<String>

The Amazon Resource Names (ARN) of the OpenID Connect providers.



118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/aws-sdk-cognitoidentity/types.rb', line 118

class CreateIdentityPoolInput < Struct.new(
  :identity_pool_name,
  :allow_unauthenticated_identities,
  :allow_classic_flow,
  :supported_login_providers,
  :developer_provider_name,
  :open_id_connect_provider_arns,
  :cognito_identity_providers,
  :saml_provider_arns,
  :identity_pool_tags)
  SENSITIVE = []
  include Aws::Structure
end

#saml_provider_arnsArray<String>

An array of Amazon Resource Names (ARNs) of the SAML provider for your identity pool.



118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/aws-sdk-cognitoidentity/types.rb', line 118

class CreateIdentityPoolInput < Struct.new(
  :identity_pool_name,
  :allow_unauthenticated_identities,
  :allow_classic_flow,
  :supported_login_providers,
  :developer_provider_name,
  :open_id_connect_provider_arns,
  :cognito_identity_providers,
  :saml_provider_arns,
  :identity_pool_tags)
  SENSITIVE = []
  include Aws::Structure
end

#supported_login_providersHash<String,String>

Optional key:value pairs mapping provider names to provider app IDs.



118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/aws-sdk-cognitoidentity/types.rb', line 118

class CreateIdentityPoolInput < Struct.new(
  :identity_pool_name,
  :allow_unauthenticated_identities,
  :allow_classic_flow,
  :supported_login_providers,
  :developer_provider_name,
  :open_id_connect_provider_arns,
  :cognito_identity_providers,
  :saml_provider_arns,
  :identity_pool_tags)
  SENSITIVE = []
  include Aws::Structure
end