Class: Aws::CognitoIdentity::Types::LookupDeveloperIdentityResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cognitoidentity/types.rb

Overview

Returned in response to a successful LookupDeveloperIdentity action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#developer_user_identifier_listArray<String>

This is the list of developer user identifiers associated with an identity ID. Cognito supports the association of multiple developer user identifiers with an identity ID.



959
960
961
962
963
964
965
# File 'lib/aws-sdk-cognitoidentity/types.rb', line 959

class LookupDeveloperIdentityResponse < Struct.new(
  :identity_id,
  :developer_user_identifier_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#identity_idString

A unique identifier in the format REGION:GUID.



959
960
961
962
963
964
965
# File 'lib/aws-sdk-cognitoidentity/types.rb', line 959

class LookupDeveloperIdentityResponse < Struct.new(
  :identity_id,
  :developer_user_identifier_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A pagination token. The first call you make will have NextToken set to null. After that the service will return NextToken values as needed. For example, let's say you make a request with MaxResults set to 10, and there are 20 matches in the database. The service will return a pagination token as a part of the response. This token can be used to call the API again and get results starting from the 11th match.



959
960
961
962
963
964
965
# File 'lib/aws-sdk-cognitoidentity/types.rb', line 959

class LookupDeveloperIdentityResponse < Struct.new(
  :identity_id,
  :developer_user_identifier_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end